/**
 * Copyright (c) 2025 Eclipse Foundation
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse
 * Public License 2.0 which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * Author: Jordi Gómez <jordi.gomez@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
package org.eclipsefoundation.git.eca.config;

import java.util.List;
import java.util.Optional;

import io.smallrye.config.ConfigMapping;

/**
 * Represents configuration for the default mailer service.
 * 
 * @author Martin Lowe
 *
 */
@ConfigMapping(prefix = "eclipse.mailer")
public interface MailerConfig {

    public RevalidationAlert revalidationAlert();

    /**
     * This interface defines the contract for specifying recipients and message configuration when sending revalidation alerts within the
     * ECA validation process.
     */
    public interface RevalidationAlert {
        public List<String> to();

        public MessageConfiguration authorMessage();
    }

    public interface MessageConfiguration {
        public Optional<String> replyTo();

        public Optional<List<String>> bcc();
    }
}
